@@ -1,7 +1,7 @@
 package Sah::Schemas::GraphicsColorNames;
 
-our $DATE = '2020-06-10'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2021-03-18'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Sah schemas related to Graphics::ColorNames
@@ -18,7 +18,7 @@ Sah::Schemas::GraphicsColorNames - Sah schemas related to Graphics::ColorNames
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schemas::GraphicsColorNames (from Perl distribution Sah-Schemas-GraphicsColorNames), released on 2020-06-10.
+This document describes version 0.003 of Sah::Schemas::GraphicsColorNames (from Perl distribution Sah-Schemas-GraphicsColorNames), released on 2021-03-18.
 
 =head1 HOMEPAGE
 
@@ -30,7 +30,7 @@ Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Graphics
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-GraphicsColorNames>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Sah-Schemas-GraphicsColorNames/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -50,7 +50,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
